@@ -17,7 +17,7 @@ log() {
 SRC_DIR=$(cd "$(dirname $0)/.." ; pwd)
 DST_DIR=$(cd "$1" ; pwd)
 
-[ -d "$DST_DIR" ] || die "Destination dir '$SRC_DIR' does not exist"
+[ -d "$DST_DIR" ] || die "Destination dir '$DST_DIR' does not exist"
 
 WORK_DIR=$(mktemp -d "$DST_DIR/yokadi-dist.XXXXXX")
 
@@ -30,7 +30,13 @@ git reset --hard HEAD
 git clean -q -dxf
 
 log "Building archives"
-./setup.py -q sdist --formats=gztar,zip
+python3 -m venv create "$WORK_DIR/venv"
+(
+    . "$WORK_DIR/venv/bin/activate"
+    pip install build
+    python -m build
+)
+rm -rf "$WORK_DIR/venv"
 
 log "Installing archive"
 cd dist/
@@ -39,18 +45,18 @@ tar xf "$YOKADI_TARGZ"
 
 ARCHIVE_DIR="$PWD/${YOKADI_TARGZ%.tar.gz}"
 
-virtualenv --python python3 "$WORK_DIR/venv"
+python3 -m venv create "$WORK_DIR/venv"
 (
     . "$WORK_DIR/venv/bin/activate"
 
     # Install Yokadi in the virtualenv and make sure it can be started
     # That ensures dependencies got installed by pip
     log "Smoke test"
-    pip3 install "$ARCHIVE_DIR"
+    pip install "$ARCHIVE_DIR"
     yokadi exit
 
     log "Installing extra requirements"
-    pip3 install -r "$ARCHIVE_DIR/extra-requirements.txt"
+    pip install -r "$ARCHIVE_DIR/extra-requirements.txt"
 
     log "Running tests"
     "$ARCHIVE_DIR/yokadi/tests/tests.py"
@@ -58,6 +64,6 @@ virtualenv --python python3 "$WORK_DIR/venv"
 
 log "Moving archives out of work dir"
 cd "$WORK_DIR/dist"
-mv ./*.tar.gz ./*.zip "$DST_DIR"
+mv *.tar.gz *.whl "$DST_DIR"
 rm -rf "$WORK_DIR"
 log "Done"
